@@ -16,9 +16,9 @@
 
 namespace Aux {
 
-typedef NetworKit::index index;
-typedef NetworKit::count count;
-typedef std::list<index> Bucket;
+using index = NetworKit::index;
+using count = NetworKit::count;
+using Bucket = std::list<index>;
 constexpr int64_t none = std::numeric_limits<int64_t>::max();
 
 /**
@@ -107,7 +107,7 @@ public:
     /**
      * @return key to given value @val.
      */
-    virtual int getKey(const index& val);
+    virtual int64_t getKey(const index& val);
 
 };
 
