@@ -1,5 +1,5 @@
 /*
- * KatzCentrality.h
+ * KatzCentrality.hpp
  *
  *  Created on: 09.01.2015
  *      Author: Henning
@@ -12,6 +12,8 @@
 
 namespace NetworKit {
 
+enum EdgeDirection : char { InEdges = 0, OutEdges = 1 };
+
 /**
  * @ingroup centrality
  * Computes the Katz centrality of the graph.
@@ -20,10 +22,11 @@ namespace NetworKit {
  * edges (as opposed to outgoing ones).
  */
 class KatzCentrality: public Centrality {
+    std::vector<double> values;
 protected:
-    double alpha; // damping
-    double beta; // constant centrality amount
-    double tol; // error tolerance
+    const double alpha; // damping
+    const double beta; // constant centrality amount
+    const double tol; // error tolerance
 
 public:
     /**
@@ -31,16 +34,20 @@ public:
      * Each iteration of the algorithm requires O(m) time. The number of iterations depends on how long it takes to reach the convergence.
      *
      * @param[in] G The graph.
-     * @param[in] alpha Damping of the matrix vector product result
+     * @param[in] alpha Damping of the matrix vector product result, must be non negative.
+     * Leave this parameter to 0 to use the default value 1 / (max_degree + 1).
      * @param[in] beta Constant value added to the centrality of each vertex
      * @param[in] tol The tolerance for convergence.
      */
-    KatzCentrality(const Graph& G, double alpha = 5e-4, double beta = 0.1, double tol = 1e-8);
+    KatzCentrality(const Graph& G, double alpha = 0, double beta = 0.1, double tol = 1e-8);
 
     /**
      * Computes katz centrality on the graph passed in constructor.
      */
     void run() override;
+
+    // Whether to count in-edges or out-edges
+    EdgeDirection edgeDirection = EdgeDirection::InEdges;
 };
 
 } /* namespace NetworKit */
