@@ -1,5 +1,5 @@
 /*
- * GraphEvent.h
+ * GraphEvent.hpp
  *
  *  Created on: 02.04.2013
  *      Author: cls
@@ -12,12 +12,10 @@
 
 namespace NetworKit {
 
-
 /**
  * @ingroup dynamics
  */
-class GraphEvent {
-
+class GraphEvent final {
 
 public:
 
@@ -27,17 +25,15 @@ public:
         NODE_RESTORATION,
         EDGE_ADDITION,
         EDGE_REMOVAL,
-        EDGE_WEIGHT_UPDATE, 
+        EDGE_WEIGHT_UPDATE,
         EDGE_WEIGHT_INCREMENT,
         TIME_STEP
-        
     };
 
-    Type type;	//!< type of graph event
-    node u; 				//!< first node parameter
-    node v;					//!< second node parameter
-    edgeweight w;			//!< edge weight parameter
-
+    Type type;  //!< type of graph event
+    node u;         //!< first node parameter
+    node v;        //!< second node parameter
+    edgeweight w;      //!< edge weight parameter
 
     GraphEvent() = default;
 
@@ -50,7 +46,6 @@ public:
      * Return string representation.
      */
     std::string toString() const;
-
 };
 
 } /* namespace NetworKit */
