@@ -81,7 +81,7 @@ private:
      * @param numVectors Number of test vectors to create.
      * @return The created test vectors.
      */
-    std::vector<Vector> generateTVs(const Matrix& matrix, Vector& tv, const count numVectors) const;
+    std::vector<Vector> generateTVs(const Matrix &matrix, Vector &tv, count numVectors) const;
 
     /**
      * Adds high degree nodes as seeds to @a status.
@@ -143,8 +143,10 @@ private:
      * @param s[out] The best seed for node @a u.
      * @return @code{True} if a seed has been found for @a u, @code{false} otherwise.
      */
-    bool findBestSeedEnergyCorrected(const Matrix& strongAdjMatrix, const Matrix& affinityMatrix, const std::vector<double>& diag, const std::vector<Vector>& tVs, const std::vector<index>& status, const index u, index& s) const;
-
+    bool findBestSeedEnergyCorrected(const Matrix &strongAdjMatrix, const Matrix &affinityMatrix,
+                                     const std::vector<double> &diag,
+                                     const std::vector<Vector> &tVs,
+                                     const std::vector<index> &status, index u, index &s) const;
 
     /**
      * Determines if the Laplacian matrix @a A can be coarsened further.
@@ -514,7 +516,7 @@ void MultiLevelSetup<Matrix>::aggregateLooseNodes(const Matrix& strongAdjMatrix,
         }
     }
 
-    if (looseNodes.size() > 0) {
+    if (!looseNodes.empty()) {
         status[looseNodes[0]] = looseNodes[0]; // mark first as seed
         for (index k = 1; k < looseNodes.size(); ++k) {
             status[looseNodes[k]] = looseNodes[0]; // first loose nodes becomes seed
@@ -570,7 +572,7 @@ void MultiLevelSetup<Matrix>::computeStrongAdjacencyMatrix(const Matrix& matrix,
 
 template<class Matrix>
 void MultiLevelSetup<Matrix>::computeAffinityMatrix(const Matrix& matrix, const std::vector<Vector>& tVs, Matrix& affinityMatrix) const {
-    assert(tVs.size() > 0);
+    assert(!tVs.empty());
 
     std::vector<index> rowIdx(matrix.numberOfRows()+1);
     std::vector<Triplet> triplets(matrix.nnz());
