@@ -14,6 +14,7 @@
 #include <networkit/auxiliary/Timer.hpp>
 #include <networkit/centrality/ApproxBetweenness.hpp>
 #include <networkit/centrality/ApproxCloseness.hpp>
+#include <networkit/centrality/ApproxElectricalCloseness.hpp>
 #include <networkit/centrality/ApproxSpanningEdge.hpp>
 #include <networkit/centrality/ApproxGroupBetweenness.hpp>
 #include <networkit/centrality/Betweenness.hpp>
@@ -41,6 +42,7 @@
 #include <networkit/distance/Dijkstra.hpp>
 #include <networkit/generators/DorogovtsevMendesGenerator.hpp>
 #include <networkit/generators/ErdosRenyiGenerator.hpp>
+#include <networkit/generators/HyperbolicGenerator.hpp>
 #include <networkit/graph/GraphTools.hpp>
 #include <networkit/io/METISGraphReader.hpp>
 #include <networkit/io/SNAPGraphReader.hpp>
@@ -85,14 +87,20 @@ TEST_F(CentralityGTest, testBetweennessCentrality) {
     Betweenness centrality(G);
     centrality.run();
     std::vector<double> bc = centrality.scores();
+    std::vector<double> result = {0., 0., 15., 3., 3., 1.};
 
     const double tol = 1e-3;
-    EXPECT_NEAR(0.0, bc[0], tol);
-    EXPECT_NEAR(0.0, bc[1], tol);
-    EXPECT_NEAR(15.0, bc[2], tol);
-    EXPECT_NEAR(3.0, bc[3], tol);
-    EXPECT_NEAR(3.0, bc[4], tol);
-    EXPECT_NEAR(1.0, bc[5], tol);
+    G.forNodes([&](node u) {
+        EXPECT_NEAR(result[u], bc[u], tol);
+    });
+
+    Betweenness centralityNorm(G, true);
+    centralityNorm.run();
+    bc = centralityNorm.scores();
+    const double pairs = (n - 1) * (n - 2);
+    G.forNodes([&](node u) {
+        EXPECT_NEAR(result[u] / pairs, bc[u], tol);
+    });
 }
 
 TEST_F(CentralityGTest, testBetweenness2Centrality) {
@@ -197,31 +205,20 @@ TEST_F(CentralityGTest, testBetweennessCentralityWeighted) {
 
 // TODO: replace by smaller graph
 TEST_F(CentralityGTest, testKatzCentralityDirected) {
-    SNAPGraphReader reader;
-    Graph G = reader.read("input/wiki-Vote.txt");
-    KatzCentrality kc(G);
+    const auto G = SNAPGraphReader{}.read("input/wiki-Vote.txt");
+    KatzCentrality kc(G, 5e-4);
 
     DEBUG("start kc run");
     kc.run();
     DEBUG("finish kc");
-    std::vector<std::pair<node, double>> kc_ranking = kc.ranking();
-    // std::vector<double> kc_scores = kc.scores();
 
-    EXPECT_EQ(kc_ranking[0].first, 699);
+    EXPECT_EQ(kc.ranking().front().first, 699);
 }
 
 TEST_F(CentralityGTest, testKatzTopk) {
-    METISGraphReader reader;
-    Graph G = reader.read("input/caidaRouterLevel.graph");
+    const auto G = METISGraphReader{}.read("input/caidaRouterLevel.graph");
 
-    // Compute max. degree to ensure that we use the same alpha for both algos.
-    count maxDegree = 0;
-    G.forNodes([&](node u) {
-        if (G.degree(u) > maxDegree)
-            maxDegree = G.degree(u);
-    });
-
-    KatzCentrality exactAlgo(G, 1.0 / (maxDegree + 1), 1.0);
+    KatzCentrality exactAlgo(G, 0, 1.0);
     DynKatzCentrality topAlgo(G, 100);
     exactAlgo.run();
     topAlgo.run();
@@ -232,18 +229,18 @@ TEST_F(CentralityGTest, testKatzTopk) {
     // node.
     auto exactRanking = exactAlgo.ranking();
     auto topRanking = topAlgo.ranking();
-    for (count i = 0; i < std::min(G.numberOfNodes(), count{100}); i++)
+    for (count i = 0; i < std::min(G.numberOfNodes(), static_cast<count>(100)); i++)
         EXPECT_NEAR(exactAlgo.score(topRanking[i].first),
                     exactRanking[i].second, 1e-6);
 }
 
 TEST_F(CentralityGTest, testKatzDynamicAddition) {
-    METISGraphReader reader;
-    Graph G = reader.read("input/caidaRouterLevel.graph");
+    Graph G = METISGraphReader{}.read("input/caidaRouterLevel.graph");
     DynKatzCentrality kc(G, 100);
     DEBUG("start kc run");
     kc.run();
     DEBUG("finish kc");
+    Aux::Random::setSeed(42, false);
     node u, v;
     do {
         u = GraphTools::randomNode(G);
@@ -258,11 +255,6 @@ TEST_F(CentralityGTest, testKatzDynamicAddition) {
     for (count i = 0; i <= std::min(kc.levelReached, kc2.levelReached); i++) {
         INFO("i = ", i);
         G.forNodes([&](node u) {
-            // if (kc.nPaths[i][u] != kc2.nPaths[i][u]) {
-            //	 INFO("i = ", i, ", node ", u, ", dyn kc paths: ",
-            // kc.nPaths[i][u], ",
-            // stat paths: ", kc2.nPaths[i][u]);
-            // }
             EXPECT_EQ(kc.nPaths[i][u], kc2.nPaths[i][u]);
         });
     }
@@ -275,8 +267,7 @@ TEST_F(CentralityGTest, testKatzDynamicAddition) {
 }
 
 TEST_F(CentralityGTest, testKatzDynamicDeletion) {
-    METISGraphReader reader;
-    Graph G = reader.read("input/caidaRouterLevel.graph");
+    Graph G = METISGraphReader{}.read("input/caidaRouterLevel.graph");
     DynKatzCentrality kc(G, 100);
     DEBUG("start kc run");
     kc.run();
@@ -311,8 +302,7 @@ TEST_F(CentralityGTest, testKatzDynamicDeletion) {
 }
 
 TEST_F(CentralityGTest, testKatzDynamicBuilding) {
-    METISGraphReader reader;
-    Graph GIn = reader.read("input/hep-th.graph");
+    Graph GIn = METISGraphReader{}.read("input/hep-th.graph");
 
     // Find a single max-degree node and add its edges to G.
     // (This guarantees that alpha is correct.)
@@ -1218,47 +1208,39 @@ TEST_P(CentralityGTest, testTopCloseness) {
     }
 }
 
-TEST_F(CentralityGTest, testTopHarmonicClosenessDirected) {
-    count size = 400;
-    count k = 10;
-    Aux::Random::setSeed(42, false);
-    Graph G1 = DorogovtsevMendesGenerator(size).generate();
-    Graph G(G1.upperNodeIdBound(), false, true);
-    G1.forEdges([&](node u, node v) {
-        G.addEdge(u, v);
-        G.addEdge(v, u);
-    });
-    HarmonicCloseness cc(G1, false);
-    cc.run();
-    TopHarmonicCloseness topcc(G, k);
-    topcc.run();
-    const edgeweight tol = 1e-7;
-    for (count i = 0; i < k; i++) {
-        EXPECT_NEAR(cc.ranking()[i].second, topcc.topkScoresList()[i], tol);
-    }
-}
+TEST_P(CentralityGTest, testTopHarmonicCloseness) {
+    const count size = 400;
+    const double tol = 1e-6;
 
-TEST_F(CentralityGTest, testTopHarmonicClosenessUndirected) {
-    count size = 400;
-    count k = 10;
-    Graph G1 = DorogovtsevMendesGenerator(size).generate();
-    Graph G(G1.upperNodeIdBound(), false, false);
-    G1.forEdges([&](node u, node v) {
-        G.addEdge(u, v);
-        G.addEdge(v, u);
-    });
-    HarmonicCloseness cc(G1, false);
-    cc.run();
-    TopHarmonicCloseness topcc(G, k);
-    topcc.run();
-    const edgeweight tol = 1e-7;
-    for (count i = 0; i < k; i++) {
-        EXPECT_NEAR(cc.ranking()[i].second, topcc.topkScoresList()[i], tol);
-    }
-    TopHarmonicCloseness topcc2(G, k);
-    topcc2.run();
-    for (count i = 0; i < k; i++) {
-        EXPECT_NEAR(cc.ranking()[i].second, topcc2.topkScoresList()[i], tol);
+    for (int seed : {1, 2, 3}) {
+        Aux::Random::setSeed(seed, false);
+        auto G = ErdosRenyiGenerator(size, 0.01, isDirected()).generate();
+        if (isWeighted()) {
+            G = GraphTools::toWeighted(G);
+            G.forEdges([&G](node u, node v) { G.setWeight(u, v, Aux::Random::probability()); });
+        }
+        HarmonicCloseness cc(G, false);
+        cc.run();
+        const auto ranking = cc.ranking();
+        for (bool useNBbound : {true, false}) {
+            for (count k : {5, 10, 20}) {
+                if (isWeighted() && useNBbound)
+                    continue;
+                TopHarmonicCloseness topcc(G, k, useNBbound);
+                topcc.run();
+
+                auto topkScores = topcc.topkScoresList();
+                EXPECT_EQ(topcc.topkNodesList().size(), k);
+                EXPECT_EQ(topkScores.size(), k);
+
+                topkScores = topcc.topkScoresList(true);
+
+                for (count i = 0; i < topkScores.size(); ++i)
+                    EXPECT_NEAR(ranking[i].second, topkScores[i], tol);
+                for (count i = k; i < topkScores.size(); ++i)
+                    EXPECT_NEAR(topkScores[i], topkScores[k - 1], tol);
+            }
+        }
     }
 }
 
@@ -1803,4 +1785,26 @@ TEST_P(CentralityGTest, testGedWalk) {
     }
 }
 
+TEST_F(CentralityGTest, testApproxElectricalCloseness) {
+    const double eps = 0.1;
+    const count n = 75;
+    for (int seed : {1, 2, 3}) {
+        Aux::Random::setSeed(seed, true);
+        auto G = HyperbolicGenerator(n, 10, 3).generate();
+        G = ConnectedComponents::extractLargestConnectedComponent(G, true);
+
+        // Create a biconnected component with size 2.
+        G.addNodes(2);
+        G.addEdge(n - 1, n);
+        G.addEdge(n, n + 1);
+
+        ApproxElectricalCloseness apx(G);
+        apx.run();
+        const auto diag = apx.getDiagonal();
+        const auto gt = apx.computeExactDiagonal(1e-12);
+        G.forNodes([&](node u) { EXPECT_NEAR(diag[u], gt[u], eps); });
+        EXPECT_EQ(apx.scores().size(), G.numberOfNodes());
+    }
+}
+
 } /* namespace NetworKit */
