@@ -147,15 +147,15 @@ void AffectedNodes::addedEdge() {
     std::vector<edgeweight> levelImprovementU(numLevelsU + 1, 0);
     std::vector<edgeweight> levelImprovementV(numLevelsV + 1, 0);
 
-    for (count i = 1; i <= numLevelsV; i++) {
-      for (count j = 1; j <= numLevelsU; j++) {
+    for (edgeweight i = 1.0; i <= numLevelsV; i++) {
+      for (edgeweight j = 1.0; j <= numLevelsU; j++) {
         levelImprovementV[i] += (numNodesOnLevelFromU[j] * 1.0 / (i + j)) -
                                 (prevNumNodesOnLevelFromU[j] * 1.0 / (i + j));
       }
     }
 
-    for (count i = 1; i <= numLevelsU; i++) {
-      for (count j = 1; j <= numLevelsV; j++) {
+    for (edgeweight i = 1.0; i <= numLevelsU; i++) {
+      for (edgeweight j = 1.0; j <= numLevelsV; j++) {
         levelImprovementU[i] += (numNodesOnLevelFromV[j] * 1.0 / (i + j)) -
                                 (prevNumNodesOnLevelFromV[j] * 1.0 / (i + j));
       }
@@ -236,8 +236,8 @@ void AffectedNodes::addedEdge() {
     // For each level from u, compute the maximum improvement
     std::vector<edgeweight> levelImprovementV(numLevelsV + 1, 0);
 
-    for (count i = 1; i <= numLevelsV; i++) {
-      for (count j = 1; j <= numLevelsU; j++) {
+    for (edgeweight i = 1.0; i <= numLevelsV; i++) {
+      for (edgeweight j = 1.0; j <= numLevelsU; j++) {
         levelImprovementV[i] += (numNodesOnLevelFromU[j] * 1.0 / (i + j)) -
                                 (prevNumNodesOnLevelFromU[j] * 1.0 / (i + j));
       }
