@@ -59,7 +59,7 @@ std::vector<GraphEvent> DGSStreamParser::getStream() {
 
             // parse commands
             if (tag.compare("st") == 0) { // clock
-                stream.push_back(GraphEvent(GraphEvent::TIME_STEP));
+                stream.emplace_back(GraphEvent::TIME_STEP);
             } else if (tag.compare("an") == 0) { // add node
                 node u = map(split[1]);
                 auto ev = GraphEvent(GraphEvent::NODE_ADDITION, u);
@@ -121,40 +121,40 @@ std::vector<GraphEvent> DGSStreamParser::getStream() {
 
             // parse commands
             if (tag.compare("st") == 0) { // clock
-                stream.push_back(GraphEvent(GraphEvent::TIME_STEP));
+                stream.emplace_back(GraphEvent::TIME_STEP);
             } else if (tag.compare("an") == 0) { // add node
                 node u = offset(std::stoul(split[1]));
-                stream.push_back(GraphEvent(GraphEvent::NODE_ADDITION, u));
+                stream.emplace_back(GraphEvent::NODE_ADDITION, u);
             } else if (tag.compare("ae") == 0) { // add edge
                 node u = offset(std::stoul(split[2]));
                 node v = offset(std::stoul(split[3]));
                 edgeweight w = std::stod(Aux::StringTools::split(split[4], '=')[1]); // weight=<w>
-                stream.push_back(GraphEvent(GraphEvent::EDGE_ADDITION, u, v, w));
+                stream.emplace_back(GraphEvent::EDGE_ADDITION, u, v, w);
             } else if (tag.compare("ce") == 0) {
                 // update edge. Only the "weight" attribute is supported so far
                 std::vector<std::string> uvs = Aux::StringTools::split(split[1], '-');
                 node u = offset(std::stoul(uvs[0]));
                 node v = offset(std::stoul(uvs[1]));
                 edgeweight w = std::stod(Aux::StringTools::split(split[2], '=')[1]); // weight=<w>
-                stream.push_back(GraphEvent(GraphEvent::EDGE_WEIGHT_UPDATE, u, v, w));
+                stream.emplace_back(GraphEvent::EDGE_WEIGHT_UPDATE, u, v, w);
             } else if (tag.compare("ie") == 0) {
                 // update edge. Only the "weight" attribute is supported so far
                 std::vector<std::string> uvs = Aux::StringTools::split(split[1], '-');
                 node u = offset(std::stoul(uvs[0]));
                 node v = offset(std::stoul(uvs[1]));
                 edgeweight w = std::stod(Aux::StringTools::split(split[2], '=')[1]); // weight=<w>
-                stream.push_back(GraphEvent(GraphEvent::EDGE_WEIGHT_INCREMENT, u, v, w));
+                stream.emplace_back(GraphEvent::EDGE_WEIGHT_INCREMENT, u, v, w);
             } else if (tag.compare("de") == 0) {
                 std::vector<std::string> uvs = Aux::StringTools::split(split[1], '-');
                 node u = offset(std::stoul(uvs[0]));
                 node v = offset(std::stoul(uvs[1]));
-                stream.push_back(GraphEvent(GraphEvent::EDGE_REMOVAL, u, v));
+                stream.emplace_back(GraphEvent::EDGE_REMOVAL, u, v);
             } else if (tag.compare("dn") == 0) {
                 node u = offset(std::stoul(split[1]));
-                stream.push_back(GraphEvent(GraphEvent::NODE_REMOVAL, u));
+                stream.emplace_back(GraphEvent::NODE_REMOVAL, u);
             } else if (tag.compare("rn") == 0) {
                 node u = offset(std::stoul(split[1]));
-                stream.push_back(GraphEvent(GraphEvent::NODE_RESTORATION, u));
+                stream.emplace_back(GraphEvent::NODE_RESTORATION, u);
             } else {
                 ERROR("malformed line (" , lineCount , ") : " , line);
                 throw std::runtime_error("malformed line in .DGS file");
